@@ -65,7 +65,30 @@
 ;;; -*- news-list -*-
 
 (defconst wl-news-news-alist
-  '(("en" ((2 12 2) . "* Changes in 2.12.2 from 2.12.0
+  '(("en" ((2 14 0) . "* Changes in 2.14.0 from 2.12.2
+
+** New folder type `access' is added.
+   In `access' folder, sub-folders of the specified folder can be treated
+   as one folder.
+
+** Synchronization speed of the folder is improved.
+   The function which calculates list diff is re-wrote and is faster
+   than previous implementation, especially in the folders with large
+   number of the messages.
+
+** New event handling mechanism is incorporated.
+
+** Improved the disconnected operations for IMAP draft saving.
+   There was a bug of message numbering in the disconnected imap draft.
+   It is fixed using new event handling mechanism.
+
+** `Shimbun' summary buffers are updated dynamically.
+   Some shimbun folder does not have correct information.
+   In this version, they are corrected using the message body after retrieval.
+   It is implemented with new event handling mechanism.
+
+** Many bug fixes.
+") ((2 12 2) . "* Changes in 2.12.2 from 2.12.0
   Version 2.12.2 is a bug fix version of 2.12.0.
 
 ** Now Maildir is usable on Windows systems.
@@ -816,7 +839,30 @@ wl-prefetch-confirm-threshold, wl-cache-fetch-threshold.
   wl-address-user-mail-address-p
   wl-summary-jump-to-msg-by-message-id-via-nntp
   wl-summary-temp-mark-pick
-")) ("ja" ((2 12 2) . "* 2.12.0 $(B$+$i(B 2.12.2 $(B$X$NJQ99E@(B
+")) ("ja" ((2 14 0) . "* 2.12.2 $(B$+$i(B 2.14.0 $(B$X$NJQ99E@(B
+
+** $(B?7$7$$%U%)%k%@7?(B access $(B%U%)%k%@$,DI2C$5$l$^$7$?!#(B
+   $(B;XDj$5$l$?%U%)%k%@$NG[2<$N%5%V%U%)%k%@$r2>A[E*$K0l$D$N%U%)%k%@$H$7$F07$((B
+   $(B$k$h$&$K$9$k%U%)%k%@$G$9!#(B
+
+** $(B%U%)%k%@$N%"%C%W%G!<%H$,9bB.2=$5$l$^$7$?!#(B
+   $(B%j%9%H$N:9J,$r7W;;$9$k4X?t$,=q$-D>$5$l!"FC$KB?$/$N%a%C%;!<%8$r4^$`%U%)(B
+   $(B%k%@$G$NF0:n$,9bB.$K$J$j$^$7$?!#(B
+
+** $(B?7$7$$%$%Y%s%H%O%s%I%j%s%05!G=$,DI2C$5$l$^$7$?!#(B
+
+** $(B%I%i%U%H%U%)%k%@$K(B IMAP $(B%U%)%k%@$r;XDj$7$F$$$k>l9g$NIT6q9g$,2~A1$5$l$^$7$?!#(B
+   $(B%*%U%i%$%s>uBV$G%I%i%U%H$rJ]B8$9$k$H$-$N5sF0$K%P%0$,$"$j$^$7$?$,!"?7$7$$(B
+   $(B%$%Y%s%H%O%s%I%j%s%05!G=$rMQ$$$F=$@5$5$l$^$7$?!#(B
+
+** `Shimbun' $(B$N%5%^%j$,F0E*$K99?7$5$l$^$9!#(B
+   $(B$$$/$D$+$N(B shimbun $(B%U%)%k%@$O!"%5%^%j$N>pJs$,@5$7$/$"$j$^$;$s!#(B
+   $(B$3$N%P!<%8%g%s$+$i!"%a%C%;!<%8$r<h$j$h$;$?$H$-$N>pJs$rMQ$$$F%5%^%j$,(B
+   $(B<+F0E*$K=$@5$5$l$k$h$&$K$J$j$^$7$?!#$3$N<BAu$K$O!"?7$7$$%$%Y%s%H%O%s%I(B
+   $(B%j%s%05!G=$,MQ$$$i$l$F$$$^$9!#(B
+
+** $(B$=$NB>B?$/$N%P%0=$@5!#(B
+") ((2 12 2) . "* 2.12.0 $(B$+$i(B 2.12.2 $(B$X$NJQ99E@(B
   2.12.2 $(B$O!"(B2.12.0 $(B$N%P%0=$@5HG$G$9!#(B
 
 ** Windows $(B$G(B Maildir $(B$,;H$($k$h$&$K$J$j$^$7$?!#(B
@@ -840,11 +886,11 @@ wl-prefetch-confirm-threshold, wl-cache-fetch-threshold.
 
 ** $(B%U%i%0$,!"8!:w;~Ey$NJd408uJd$H$7$F8=$l$k$h$&$K$J$j$^$7$?!#(B
 
+** Folder mode $(B$G%"%/%;%9%0%k!<%W(B \"@/\" $(B$NE83+$,@5$7$/F0:n$7$^$9!#(B
+
 ** $(B%U%i%0L>$K$h$C$F$O4V0c$C$?%U%i%0%U%)%k%@$,:n@.$5$l$kLdBj$,=$@5$5$l$^$7$?!#(B
    $(B%U%i%0$K(B [a-z]$(B0J30$NJ8;z$r;H$C$?$H$-$NLdBj$KBP=h$7$^$7$?!#(B
 
-** Folder mode $(B$G%"%/%;%9%0%k!<%W(B \"@/\" $(B$NE83+$,@5$7$/F0:n$7$^$9!#(B
-
 ** $(B%I%i%U%H$N<+F0J]B8;~$K%(%i!<$K$J$C$F$7$^$&LdBj$,=$@5$5$l$^$7$?!#(B
 
 ** $(B%"%I%l%9%^%M!<%8%c$r5/F0$7$?:]$K%(%i!<$K$J$kLdBj$,=$@5$5$l$^$7$?!#(B
@@ -1682,15 +1728,18 @@ wl-prefetch-confirm-threshold, wl-cache-fetch-threshold.
   (define-key wl-news-mode-map "a"     'wl-news-show-all)
   (define-key wl-news-mode-map "m"     'wl-news-append-to-folder)
   (define-key wl-news-mode-map "\C-m"  'wl-news-next-line)
-  (define-key wl-news-mode-map " "     'wl-news-next-page))
+  (define-key wl-news-mode-map " "     'wl-news-next-page)
+  (define-key wl-news-mode-map "\177"  'wl-news-previous-page)
+  ;; re-bind commands of outline-mode
+  (define-key wl-news-mode-map "n"     'outline-next-visible-heading)
+  (define-key wl-news-mode-map "p"     'outline-previous-visible-heading)
+  (define-key wl-news-mode-map "u"     'outline-up-heading)
+  (define-key wl-news-mode-map "N"     'outline-forward-same-level)
+  (define-key wl-news-mode-map "P"     'outline-backward-same-level))
 
-(defun wl-news-mode ()
+(require 'derived)
+(define-derived-mode wl-news-mode outline-mode "NEWS"
   "Mode for Wanderlust NEWS(.ja)."
-  (interactive)
-  (kill-all-local-variables)
-  (use-local-map wl-news-mode-map)
-  (setq major-mode 'wl-news-mode)
-  (setq mode-name "NEWS")
   (setq buffer-read-only t))
 
 (defun wl-news (&optional arg)
@@ -1734,6 +1783,10 @@ wl-prefetch-confirm-threshold, wl-cache-fetch-threshold.
   (interactive)
   (scroll-up))
 
+(defun wl-news-previous-page ()
+  (interactive)
+  (scroll-down))
+
 (defun wl-news-show-all ()
   (interactive)
   (when (eq major-mode 'wl-news-mode)
